@@ -24,6 +24,9 @@
 #include "box_data.h"
 #include "../utility_widgets/db_adddel/db_adddel_withbuttons.h"
 
+namespace Glom
+{
+
 class Box_Data_List : public Box_Data
 {
 public: 
@@ -36,6 +39,9 @@ public:
   virtual Gnome::Gda::Value get_primary_key_value_selected();
   Gnome::Gda::Value get_primary_key_value_first();
 
+  ///This allows Box_Data::record_new() to set the generated/entered primary key value, needed by Box_Data_List:
+  virtual void set_primary_key_value(const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& value);
+
   virtual Gnome::Gda::Value get_entered_field_data(const sharedptr<const LayoutItem_Field>& field) const;
   virtual void set_entered_field_data(const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
   virtual void set_entered_field_data(const Gtk::TreeModel::iterator& row, const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
@@ -59,7 +65,7 @@ public:
   virtual void on_details_nav_previous();
   virtual void on_details_nav_next();
   virtual void on_details_nav_last();
-  virtual void on_Details_record_deleted(const Gnome::Gda::Value& primary_key_value);
+  virtual void on_details_record_deleted(const Gnome::Gda::Value& primary_key_value);
 
   void get_record_counts(gulong& total, gulong& found) const;
 
@@ -82,11 +88,9 @@ protected:
 
   virtual void on_adddel_user_changed(const Gtk::TreeModel::iterator& row, guint col);
 
-  virtual void on_record_added(const Gnome::Gda::Value& primary_key_value); //Not a signal handler. To be overridden.
+  virtual void on_record_added(const Gnome::Gda::Value& primary_key_value, const Gtk::TreeModel::iterator& row); //Not a signal handler. To be overridden.
   virtual void on_record_deleted(const Gnome::Gda::Value& primary_key_value);
 
-  virtual bool get_field_column_index(const Glib::ustring& field_name, guint& index) const;
-
   virtual void print_layout();
   virtual void print_layout_group(xmlpp::Element* node_parent, const sharedptr<const LayoutGroup>& group);
 
@@ -99,4 +103,6 @@ protected:
   type_signal_user_requested_details m_signal_user_requested_details;
 };
 
+} //namespace Glom
+
 #endif
